{% load static %}
<!DOCTYPE html>
<html>
    <head>
        <link rel="icon" href="/static/images/favicon.ico" type="image/x-icon" />
        <meta charset="utf-8">
        <title> bamboo-engine-admin-frontend </title>
    <link href="{% static 'engine_admin/css/app.903f13e.css' %}" rel="stylesheet"></head>
    <body>
        <div id="app"></div>
        <script>
            var SITE_URL = '{{SITE_URL}}'
            var BK_STATIC_URL = '{{BK_STATIC_URL}}/'
            var REMOTE_STATIC_URL = ''
        </script>
        <script>
            var pathname = window.location.pathname
            var SITE_URL = pathname.endsWith('/') ? pathname : pathname + '/'
        </script>
    <script type="text/javascript" src="{% static 'engine_admin/js/runtime.114327c.js' %}"></script><script type="text/javascript" src="{% static 'engine_admin/js/vue-lib.ac90813.js' %}"></script><script type="text/javascript" src="{% static 'engine_admin/js/app.442a902.js' %}"></script></body>
</html>
